From eb90a298c3910db3659c48d3d06f0aa56250c34b Mon Sep 17 00:00:00 2001
From: reshke kirill <reshke@double.cloud>
Date: Fri, 2 Aug 2024 08:23:10 +0000
Subject: [PATCH v2] Rename LOCKMODE type vairables to lockmode.

This way code looks more consistent.
---
 src/backend/commands/vacuum.c   |  6 +++---
 src/backend/storage/lmgr/lock.c | 10 +++++-----
 src/include/commands/vacuum.h   |  2 +-
 src/include/storage/lock.h      |  4 ++--
 4 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/src/backend/commands/vacuum.c b/src/backend/commands/vacuum.c
index 48f8eab202..2b000d944c 100644
--- a/src/backend/commands/vacuum.c
+++ b/src/backend/commands/vacuum.c
@@ -756,7 +756,7 @@ vacuum_is_permitted_for_relation(Oid relid, Form_pg_class reltuple,
  */
 Relation
 vacuum_open_relation(Oid relid, RangeVar *relation, bits32 options,
-					 bool verbose, LOCKMODE lmode)
+					 bool verbose, LOCKMODE lockmode)
 {
 	Relation	rel;
 	bool		rel_lock = true;
@@ -774,8 +774,8 @@ vacuum_open_relation(Oid relid, RangeVar *relation, bits32 options,
 	 * in non-blocking mode, before calling try_relation_open().
 	 */
 	if (!(options & VACOPT_SKIP_LOCKED))
-		rel = try_relation_open(relid, lmode);
-	else if (ConditionalLockRelationOid(relid, lmode))
+		rel = try_relation_open(relid, lockmode);
+	else if (ConditionalLockRelationOid(relid, lockmode))
 		rel = try_relation_open(relid, NoLock);
 	else
 	{
diff --git a/src/backend/storage/lmgr/lock.c b/src/backend/storage/lmgr/lock.c
index 0400a50777..02408cc022 100644
--- a/src/backend/storage/lmgr/lock.c
+++ b/src/backend/storage/lmgr/lock.c
@@ -567,11 +567,11 @@ ProcLockHashCode(const PROCLOCKTAG *proclocktag, uint32 hashcode)
  * Given two lock modes, return whether they would conflict.
  */
 bool
-DoLockModesConflict(LOCKMODE mode1, LOCKMODE mode2)
+DoLockModesConflict(LOCKMODE lockmode1, LOCKMODE lockmode2)
 {
 	LockMethod	lockMethodTable = LockMethods[DEFAULT_LOCKMETHOD];
 
-	if (lockMethodTable->conflictTab[mode1] & LOCKBIT_ON(mode2))
+	if (lockMethodTable->conflictTab[lockmode1] & LOCKBIT_ON(lockmode2))
 		return true;
 
 	return false;
@@ -4057,11 +4057,11 @@ GetRunningTransactionLocks(int *nlocks)
 
 /* Provide the textual name of any lock mode */
 const char *
-GetLockmodeName(LOCKMETHODID lockmethodid, LOCKMODE mode)
+GetLockmodeName(LOCKMETHODID lockmethodid, LOCKMODE lockmode)
 {
 	Assert(lockmethodid > 0 && lockmethodid < lengthof(LockMethods));
-	Assert(mode > 0 && mode <= LockMethods[lockmethodid]->numLockModes);
-	return LockMethods[lockmethodid]->lockModeNames[mode];
+	Assert(lockmode > 0 && lockmode <= LockMethods[lockmethodid]->numLockModes);
+	return LockMethods[lockmethodid]->lockModeNames[lockmode];
 }
 
 #ifdef LOCK_DEBUG
diff --git a/src/include/commands/vacuum.h b/src/include/commands/vacuum.h
index 759f9a87d3..328f2b1223 100644
--- a/src/include/commands/vacuum.h
+++ b/src/include/commands/vacuum.h
@@ -344,7 +344,7 @@ extern bool vacuum_is_permitted_for_relation(Oid relid, Form_pg_class reltuple,
 											 bits32 options);
 extern Relation vacuum_open_relation(Oid relid, RangeVar *relation,
 									 bits32 options, bool verbose,
-									 LOCKMODE lmode);
+									 LOCKMODE lockmode);
 extern IndexBulkDeleteResult *vac_bulkdel_one_index(IndexVacuumInfo *ivinfo,
 													IndexBulkDeleteResult *istat,
 													TidStore *dead_items,
diff --git a/src/include/storage/lock.h b/src/include/storage/lock.h
index cc1f6e78c3..adf31ae327 100644
--- a/src/include/storage/lock.h
+++ b/src/include/storage/lock.h
@@ -548,7 +548,7 @@ extern void InitLocks(void);
 extern LockMethod GetLocksMethodTable(const LOCK *lock);
 extern LockMethod GetLockTagsMethodTable(const LOCKTAG *locktag);
 extern uint32 LockTagHashCode(const LOCKTAG *locktag);
-extern bool DoLockModesConflict(LOCKMODE mode1, LOCKMODE mode2);
+extern bool DoLockModesConflict(LOCKMODE lockmode1, LOCKMODE lockmode2);
 extern LockAcquireResult LockAcquire(const LOCKTAG *locktag,
 									 LOCKMODE lockmode,
 									 bool sessionLock,
@@ -589,7 +589,7 @@ extern LockData *GetLockStatusData(void);
 extern BlockedProcsData *GetBlockerStatusData(int blocked_pid);
 
 extern xl_standby_lock *GetRunningTransactionLocks(int *nlocks);
-extern const char *GetLockmodeName(LOCKMETHODID lockmethodid, LOCKMODE mode);
+extern const char *GetLockmodeName(LOCKMETHODID lockmethodid, LOCKMODE lockmode);
 
 extern void lock_twophase_recover(TransactionId xid, uint16 info,
 								  void *recdata, uint32 len);
-- 
2.34.1

